@@ -72,31 +72,33 @@
 (defun riece-command-next-channel ()
   "Select the next channel."
   (interactive)
-  (let ((pointer (cdr (string-list-member-ignore-case
-		       riece-current-channel
-		       riece-current-channels))))
-    (while (and pointer
-		(null (car pointer)))
-      (setq pointer (cdr pointer)))
-    (if (car pointer)
-	(riece-command-switch-to-channel (car pointer))
-      (error "No such channel!"))))
+  (when (> (length riece-current-channels) 1)
+    (let ((pointer (cdr (string-list-member-ignore-case
+			 riece-current-channel
+			 riece-current-channels))))
+      (while (and pointer
+		  (null (car pointer)))
+	(setq pointer (cdr pointer)))
+      (if (car pointer)
+	  (riece-command-switch-to-channel (car pointer))
+	(error "No such channel!")))))
 
 (defun riece-command-previous-channel ()
   "Select the previous channel."
   (interactive)
-  (let ((pointer (string-list-member-ignore-case
-		  riece-current-channel
-		  riece-current-channels))
-	(start riece-current-channels)
-	channel)
-    (while (and start (not (eq start pointer)))
-      (if (car start)
-	  (setq channel (car start)))
-      (setq start (cdr start)))
-    (if channel
-	(riece-command-switch-to-channel channel)
-      (error "No such channel!"))))
+  (when (> (length riece-current-channels) 1)
+    (let ((pointer (string-list-member-ignore-case
+		    riece-current-channel
+		    riece-current-channels))
+	  (start riece-current-channels)
+	  channel)
+      (while (and start (not (eq start pointer)))
+	(if (car start)
+	    (setq channel (car start)))
+	(setq start (cdr start)))
+      (if channel
+	  (riece-command-switch-to-channel channel)
+	(error "No such channel!")))))
 
 (defun riece-command-select-command-buffer ()
   "Select the command buffer."
@@ -112,19 +114,22 @@
 (defun riece-command-toggle-channel-buffer-mode ()
   (interactive)
   (setq riece-channel-buffer-mode
-	(not riece-channel-buffer-mode))
+	(not riece-channel-buffer-mode)
+	riece-save-variables-are-dirty t)
   (riece-command-configure-windows))
 
 (defun riece-command-toggle-user-list-buffer-mode ()
   (interactive)
   (setq riece-user-list-buffer-mode
-	(not riece-user-list-buffer-mode))
+	(not riece-user-list-buffer-mode)
+	riece-save-variables-are-dirty t)
   (riece-command-configure-windows))
 
 (defun riece-command-toggle-channel-list-buffer-mode ()
   (interactive)
   (setq riece-channel-list-buffer-mode
-	(not riece-channel-list-buffer-mode))
+	(not riece-channel-list-buffer-mode)
+	riece-save-variables-are-dirty t)
   (riece-command-configure-windows))
 
 (defun riece-command-finger (user &optional recurse)
@@ -209,6 +214,19 @@
 	  (yes-or-no-p "Really want to query WHO without argument? "))
       (riece-send-string (format "WHO %s\r\n" pattern))))
 
+(defun riece-command-list (pattern)
+  (interactive
+   (let ((completion-ignore-case t))
+     (list (read-from-minibuffer
+	    "Pattern: "
+	    (if (and riece-current-channel
+		     (riece-channel-p riece-current-channel))
+		(cons (riece-identity-prefix riece-current-channel)
+		      0))))))
+  (if (or (not (equal pattern ""))
+	  (yes-or-no-p "Really want to query LIST without argument? "))
+      (riece-send-string (format "LIST %s\r\n" pattern))))
+
 (defun riece-command-change-mode (channel change)
   (interactive
    (let* ((completion-ignore-case t)
@@ -299,25 +317,43 @@
 		   (make-string (length group) ?v)
 		   (mapconcat #'identity group " ")))))))
 
-(defun riece-command-send-message (message)
+(defun riece-command-send-message (message notice)
   "Send MESSAGE to the current channel."
   (if (equal message "")
       (error "No text to send"))
   (unless riece-current-channel
     (error (substitute-command-keys
 	    "Type \\[riece-command-join] to join a channel")))
-  (riece-send-string
-   (format "PRIVMSG %s :%s\r\n"
-	   (riece-identity-prefix riece-current-channel)
-	   message))
-  (riece-own-channel-message message))
+  (if notice
+      (progn
+	(riece-send-string
+	 (format "NOTICE %s :%s\r\n"
+		 (riece-identity-prefix riece-current-channel)
+		 message))
+	(riece-own-channel-message message riece-current-channel 'notice))
+    (riece-send-string
+     (format "PRIVMSG %s :%s\r\n"
+	     (riece-identity-prefix riece-current-channel)
+	     message))
+    (riece-own-channel-message message)))
 
 (defun riece-command-enter-message ()
   "Send the current line to the current channel."
   (interactive)
   (riece-command-send-message (buffer-substring
 			       (riece-line-beginning-position)
-			       (riece-line-end-position)))
+			       (riece-line-end-position))
+			      nil)
+  (let ((next-line-add-newlines t))
+    (next-line 1)))
+
+(defun riece-command-enter-message-as-notice ()
+  "Send the current line to the current channel as NOTICE."
+  (interactive)
+  (riece-command-send-message (buffer-substring
+			       (riece-line-beginning-position)
+			       (riece-line-end-position))
+			      t)
   (let ((next-line-add-newlines t))
     (next-line 1)))
 
@@ -520,14 +556,11 @@ If prefix argument ARG is non-nil, toggle frozen status."
 (defun riece-command-open-server (server-name)
   (interactive
    (list (completing-read "Server: " riece-server-alist)))
-  (let ((process (riece-start-server
-		  (riece-server-name-to-server server-name)
-		  server-name)))
-    (with-current-buffer (process-buffer process)
-      (setq riece-server-name server-name))
-    (setq riece-server-process-alist
-	  (cons (cons server-name process)
-		riece-server-process-alist))))
+  (if (assoc server-name riece-server-process-alist)
+      (error "%s is already opened" server-name)
+    (riece-open-server
+     (riece-server-name-to-server server-name)
+     server-name)))
 
 (defun riece-command-close-server (server-name &optional message)
   (interactive
